//***********************************************************************************//
//*	Project:																		*//
//*																					*//
//*	File:		main.c			 													*//
//*	Version:	1.0																	*//
//*																					*//
//*	Author:		Bob Marlowe															*//
//*	(C) 2018	Jörg Meier Software - Entwicklung briefe@jmeiersoftware.de			*//
//***********************************************************************************//
//***********************************************************************************//
//*																					*//
//*		Principles of Operation														*//
//*																					*//
//*		Controlling up to 10 RC servos programmatically using a Servos component	*//
//*																					*//
//***********************************************************************************//

//***********************************************************************************//
//**************** Libraries ********************************************************//
//***********************************************************************************//
#include <project.h>

//***********************************************************************************//
//**************** Definitions and Macros *******************************************//
//***********************************************************************************//
#define forever			(1)					//	I like that
#define Wait(x)								//	Empty function for better readability
#define	FALSE			(0)					
#define TRUE			(!FALSE)

//***********************************************************************************//
//******************* Structs, Typedefs and Enums ***********************************//
//***********************************************************************************//
//	None yet					

//***********************************************************************************//
//******************* Global Data Area **********************************************//
//***********************************************************************************//
//	None yet

//***********************************************************************************//
//****************** Prototypes *****************************************************//
//***********************************************************************************//
//	None yet

//***********************************************************************************//
//**************** Program Area *****************************************************//
//***********************************************************************************//

void InitializeSystem(void)								//	Start all components, initialize  variables, perform self-test
{
uint8 ii;
uint8 PosIncr;	
	CyGlobalIntEnable;									//	Enable interrupt handling
	MyServos_Start();									//	Setup the servos, default now is mid-position
	
	PosIncr= 100 / MyServos_NumServos;				// Calculate equal distant positions
	for(ii = 0; ii < MyServos_NumServos; ii++)		
	{
		MyServos_SetServo(ii,PosIncr/2 + ii*PosIncr);	//	Set positions ie: 12,37,62,87
	}
}
//***********************************************************************************//

int main()
{
static int8 Percent;
static int8 Delta[MyServos_NumServos];				//	Currently set delta for each servo
static int8 ActDelta;
static uint8 ii;

	InitializeSystem();
	
	MyServos_MoveServos();								//	Start moving the servos right now
	
	for(ii = 0; ii < MyServos_NumServos; ii++)
	{
		Percent = MyServos_GetServo(ii);				//	Read currently set servo position
		Delta[ii] = 2;									//	increase/decrease by 2
	}
	
	while(forever)										//	*** Main loop
	{
		while(!MyServos_CycleDone) Wait();						//	Wait until transmission completed
		MyServos_CycleDone = TRUE;
		for(ii = 0; ii < MyServos_NumServos; ii++)
		{
			Percent = MyServos_GetServo(ii);					//	Actual position
			ActDelta = Delta[ii];								//	Actual increment (can be negative)
			if(ActDelta < 0)
			{
				if((Percent < -ActDelta))						//	Keep within limits
					Delta[ii] = -Delta[ii];						//	Change direction
			}
			else
			{
				if((Percent + ActDelta) > 100)
					Delta[ii] = -Delta[ii];						//	Change direction
			}
			Percent += Delta[ii];								//	Increment
			MyServos_SetServo(ii,Percent);						//	Set new position
		}
		CyDelay(100);											//	200ms time to settle the servos
	}
}
//***********************************************************************************//

